@@ -6,9 +6,9 @@ from aiohttp_retry import ExponentialRetry, RetryClient
 
 from qiniu import put_file, put_data, Auth, etag
 from qiniu import BucketManager, build_batch_delete
+from qiniu import Zone, set_default
 
 from hamunafs.backends.base import BackendBase
-from aiohttp_retry import ExponentialRetry, RetryClient
 from aiofile import AIOFile, Writer
 
 class Qiniu(BackendBase):
@@ -18,6 +18,13 @@ class Qiniu(BackendBase):
         self.domain = domain
         self.default_bucket = default_bucket
         self.bucket = BucketManager(self.auth)
+
+        zone = Zone(
+            up_host='https://up.qiniup.com',
+            up_host_backup='https://upload.qiniup.com',
+            io_host='http://iovip.qbox.me',
+            scheme='https')
+        set_default(default_zone=zone)
     
     def get_token(self, filename):
         return self.auth.upload_token(self.default_bucket, filename)
