@@ -2,10 +2,10 @@ from async_timeout import asyncio
 from diskcache import Cache
 from threading import Lock
 
-import qiniu
 from hamunafs.utils.singleton_wrapper import Singleton
 from hamunafs.utils.redisutil import XRedis
 from hamunafs.utils.nsqmanager import MQManager
+from hamunafs.utils.mqtt import MQTTClient
 from hamunafs.backends import BackendBase, backend_factory
 from hamunafs.conf import REDIS, NSQ
 
@@ -38,12 +38,6 @@ class Client(Singleton):
             redis_client = XRedis(REDIS['host'], REDIS['pass'], REDIS['port'], REDIS['db'])
         self.redis = redis_client
         
-        # if mq_manager is None:
-        #     mq_manager = MQManager(NSQ['host'], NSQ['port'], async_mq=async_mq_mode)
-        #     if async_mq_mode:
-        #         if custom_async_loop is None:
-        #             custom_async_loop = asyncio.get_event_loop()
-        #         custom_async_loop.run_until_complete(mq_manager._init_async())
         self.mq = mq_manager
         self.async_mq = async_mq_mode
         self.lock = Lock()
@@ -54,10 +48,19 @@ class Client(Singleton):
         
         self.put_topic = 'fs_put'
         self.get_topic = 'fs_get'
+
+        mqtt_client = MQTTClient('fs_server', 'opush', 'innovation').connect('kafka.ai.hamuna.club', 1883)
+        mqtt_client.subscribe('fs_backend_update', 2)
+        mqtt_client.register_on_message_handler(self.__on_mqtt_message)
         
         self.update()
         self._inited = True
 
+    
+    def __on_mqtt_message(self, client, userdata, msg):
+        if msg.topic == 'fs_backend_update':
+            self.update()
+
     def get_qiniu_token(self, fname):
         qiniu_backend_keys = [k for k in list(self.backend_pools.keys()) if k.startswith('qiniu')]
         if len(qiniu_backend_keys) > 0:
@@ -66,9 +69,9 @@ class Client(Singleton):
             return backend.get_token(fname)
         return None
     
-    def update(self):
+    def update(self, force=False):
         with self.lock:
-            if self._inited:
+            if self._inited and not force:
                 return
 
             print('updating backends...')
@@ -91,8 +94,10 @@ class Client(Singleton):
     def _random_pick_backend(self) -> BackendBase:
         with self.lock:
             keys = list(self.backend_pools.keys())
+
+            selected_ind = int(random.uniform(0, len(keys)))
             
-            selected_key = random.sample(keys, 1)[0]
+            selected_key = keys[selected_ind]
             return selected_key, self.backend_pools[selected_key]
     
     def _get_appropriate_backend(self, url):
